@@ -34,9 +34,9 @@ jagsmodel_clmm <- function(info) {
     nonprop <- lapply(write_nonprop(info), add_linebreaks, indent = indent + 2)
 
     paste0("\n\n",
-         paste0(tab(4), "eta_", info$varname, "_", seq_along(nonprop),
-                "[", index, "] <- ", nonprop, collapse = "\n")
-  )}
+           paste0(tab(4), "eta_", info$varname, "_", seq_along(nonprop),
+                  "[", index, "] <- ", nonprop, collapse = "\n")
+    )}
 
 
   # syntax to set values of dummy variables,
@@ -152,24 +152,27 @@ clmm_in_jm <- function(info) {
   # syntax to set values of dummy variables,
   # e.g. "M_lvlone[i, 8] <- ifelse(M_lvlone[i, 4] == 2, 1, 0)"
   dummies <- if (!is.null(info$dummy_cols)) {
-    paste0(tab(),
-           paste_dummies(resp_mat = paste0(info$resp_mat, "gk"),
-                         resp_col = paste0(info$resp_col, ', k'),
-                         dummy_cols = paste0(info$dummy_cols, ', k'),
-                         index = index, refs = info$refs),
-           collapse = "\n")
+    paste0(
+      paste_dummies(resp_mat = paste0(info$resp_mat, "gk"),
+                    resp_col = paste0(info$resp_col, ', 1:15'),
+                    dummy_cols = paste0(info$dummy_cols, ', 1:15'),
+                    index = index, refs = info$refs),
+      collapse = "\n")
   }
 
+
   # write model ----------------------------------------------------------------
-  paste0(tab(6), info$resp_mat, "gk[", index, ", ", info$resp_col,
+  paste0(tab(4), "# calculate ", info$varname, " at the event times\n",
+         tab(4), "for (k in 1:15) {\n",
+         tab(6), info$resp_mat, "gk[", index, ", ", info$resp_col,
          ", k] ~ dcat(pgk_", info$varname, "[", index, ", 1:", info$ncat,
          ", k])", "\n",
-
          tab(6), 'etagk_', info$varname, "[", index, ", k] <- ",
-         add_linebreaks(Z_predictor, indent = 12 + nchar(info$varname) + 10),
+         add_linebreaks(Z_predictor, indent = 10 + nchar(info$varname) + 14),
          "\n\n",
-         write_probs(info, index, isgk = TRUE, indent = 6), "\n\n",
-         write_logits(info, index, isgk = TRUE, indent = 6), "\n\n",
+         write_probs(info, index, isgk = TRUE, indent = 6L), "\n\n",
+         write_logits(info, index, isgk = TRUE, indent = 6L), "\n\n",
+         tab(4), "}\n",
          dummies,
          "\n"
   )
