@@ -1,6 +1,6 @@
 library("JointAI")
 
-Sys.setenv(IS_CHECK = "true")
+# Sys.setenv(IS_CHECK = "true")
 
 skip_on_cran()
 
@@ -91,33 +91,27 @@ test_that("MCMC samples can be plottet", {
 
 
 test_that("data_list remains the same", {
-  skip_on_cran()
-  print_output(lapply(models, "[[", "data_list"), type = "value",
-               context = "survreg")
+  expect_snapshot(lapply(models, "[[", "data_list"))
 })
 
 test_that("jagsmodel remains the same", {
-  skip_on_cran()
-  print_output(lapply(models, "[[", "jagsmodel"), context = "survreg")
+  expect_snapshot(lapply(models, "[[", "jagsmodel"))
 })
 
 
 test_that("GRcrit and MCerror give same result", {
-  skip_on_cran()
-  print_output(lapply(models0, GR_crit, multivariate = FALSE),
-               context = "survreg")
-  print_output(lapply(models0, MC_error), context = "survreg")
+  expect_snapshot(lapply(models0, GR_crit, multivariate = FALSE))
+  expect_snapshot(lapply(models0, MC_error))
 })
 
 
 test_that("summary output remained the same", {
-  skip_on_cran()
-  print_output(lapply(models0, print), context = "survreg")
-  print_output(lapply(models0, coef), context = "survreg")
-  print_output(lapply(models0, confint), context = "survreg")
-  print_output(lapply(models0, summary), context = "survreg")
-  print_output(lapply(models0, function(x) coef(summary(x))),
-               context = "survreg")
+
+  expect_snapshot(lapply(models0, print))
+  expect_snapshot(lapply(models0, coef))
+  expect_snapshot(lapply(models0, confint))
+  expect_snapshot(lapply(models0, summary))
+  expect_snapshot(lapply(models0, function(x) coef(summary(x))))
 })
 
 
@@ -191,4 +185,4 @@ test_that("wrong models give errors", {
 
 })
 
-Sys.setenv(IS_CHECK = "")
+# Sys.setenv(IS_CHECK = "")
